<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

if ( ! class_exists( 'Keon_Toolset_Template_Library_Agency' ) ) {

    /**
     * Functions related to Agency Template
     * @since 1.0.0
     *
     */

    class Keon_Toolset_Template_Library_Agency extends Keon_Toolset_Template_Library_Base{
        
        /**
         * Gets an instance of this object.
         * Prevents duplicate instances which avoid artefacts and improves performance.
         *
         * @static
         * @access public
         * @since 1.0.0
         * @return object
         */
        public static function get_instance() {

            // Store the instance locally to avoid private static replication
            static $instance = null;

            // Only run these methods if they haven't been ran previously
            if ( null === $instance ) {
                $instance = new self();
            }

            // Always return the instance
            return $instance;

        }

        /**
         * Load block library
         * Used for blog template loading
         *
         * @since      1.0.0
         *
         * @param $templates_list array
         * @return array
         */
        public function add_keon_template( $templates_list ){

            $pro_state = get_state();
            $theme_slug = keon_toolset_get_theme_slug();
            
            if( isset($pro_state[$theme_slug]['agency'])){
                $is_pro = $pro_state[$theme_slug]['agency'];
            }else{
                $is_pro = true;
            }

            $keon_library_list = array(
                array(
                    'title'             => __( 'Agency', 'keon-toolset' ),
                    'is_pro'            => $is_pro,
                    'pro_url' => 'https://keonthemes.com/downloads/gutener-pro',
                    'type'              => 'template',
                    'author'            => __( 'Keon Themes', 'keon-toolset' ),
                    'keywords'          => array( 'agency', 'agency 1' ),
                    'categories'        => array( 'agency' ),
                    'template_url'      => KEON_TEMPLATE_URL.'includes/template-data/templates/gutener-agency.json',
                    'screenshot_url'    => 'https://demo.keonthemes.com/gutener/screenshots/demo8/gutener-agency-760-460.jpg',
                    'demo_url'    => 'https://demo.keonthemes.com/gutener/demo8/'
                ),
            );
            return array_merge_recursive( $keon_library_list, $templates_list );
        }
    }
}
Keon_Toolset_Template_Library_Agency::get_instance()->run();