<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

if ( ! class_exists( 'Keon_Toolset_Template_Library_Charity_NGO' ) ) {

    /**
     * Functions related to Charity NGO Template
     * @since 1.0.0
     *
     */

    class Keon_Toolset_Template_Library_Charity_NGO extends Keon_Toolset_Template_Library_Base{
        
        /**
         * Gets an instance of this object.
         * Prevents duplicate instances which avoid artefacts and improves performance.
         *
         * @static
         * @access public
         * @since 1.0.0
         * @return object
         */
        public static function get_instance() {

            // Store the instance locally to avoid private static replication
            static $instance = null;

            // Only run these methods if they haven't been ran previously
            if ( null === $instance ) {
                $instance = new self();
            }

            // Always return the instance
            return $instance;

        }

        /**
         * Load block library
         * Used for blog template loading
         *
         * @since      1.0.0
         *
         * @param $templates_list array
         * @return array
         */
        public function add_keon_template( $templates_list ){

            $pro_state = get_state();
            $theme_slug = keon_toolset_get_theme_slug();
            
            if( isset($pro_state[$theme_slug]['charity-ngo1'])){
                $is_pro1 = $pro_state[$theme_slug]['charity-ngo1'];
            }else{
                $is_pro1 = true;
            }
            if( isset($pro_state[$theme_slug]['charity-ngo2'])){
                $is_pro2 = $pro_state[$theme_slug]['charity-ngo2'];
            }else{
                $is_pro2 = true;
            }

            $keon_library_list = array(
                array(
                    'title'             => __( 'Charity NGO 1', 'keon-toolset' ),
                    'is_pro'            => $is_pro1,
                    'pro_url'           => 'https://keonthemes.com/downloads/gutener-pro',
                    'type'              => 'template',
                    'author'            => __( 'Keon Themes', 'keon-toolset' ),
                    'keywords'          => array( 'charity', 'ngo', 'charity 1', 'ngo 1' ),
                    'categories'        => array( 'charity' ),
                    'template_url'      => KEON_TEMPLATE_URL.'includes/template-data/templates/gutener-charity-ngo1.json',
                    'screenshot_url'    => 'https://demo.keonthemes.com/gutener/screenshots/demo9/gutener-charity-NGO1-760-460.jpg',
                    'demo_url'    => 'https://demo.keonthemes.com/gutener/demo9/'
                ),
                array(
                    'title'             => __( 'Charity NGO 2', 'keon-toolset' ),
                    'is_pro'            => $is_pro2,
                    'pro_url'           => 'https://keonthemes.com/downloads/gutener-pro',
                    'type'              => 'template',
                    'author'            => __( 'Keon Themes', 'keon-toolset' ),
                    'keywords'          => array( 'charity', 'ngo', 'charity 2', 'ngo 2' ),
                    'categories'        => array( 'charity' ),
                    'template_url'      => KEON_TEMPLATE_URL.'includes/template-data/templates/gutener-charity-ngo2.json',
                    'screenshot_url'    => 'https://demo.keonthemes.com/gutener/screenshots/demo109/gutener-charity-NGO-760-460.jpg',
                    'demo_url'    => 'https://demo.keonthemes.com/gutener/demo109/'
                ),
            );
            return array_merge_recursive( $keon_library_list, $templates_list );
        }
    }
}
Keon_Toolset_Template_Library_Charity_NGO::get_instance()->run();